package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.BmsportHandlingFee;
import com.steerinfo.dil.service.impl.BmsportHandlingFeeServiceImpl;
import com.steerinfo.dil.service.impl.BmsshipStatementServiceImpl;
import com.steerinfo.dil.service.impl.BmstruckFormulaServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/27 17:34
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/bmsporthandlingfee")
public class BmsportHandlingFeeController extends BaseRESTfulController {

    @Autowired
    BmsportHandlingFeeServiceImpl bmsportHandlingFeeService;
    @Autowired
    BmsshipStatementServiceImpl bmsshipStatementService;
    @Autowired
    BmstruckFormulaServiceImpl bmstruckFormulaService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;

    /**
     * 展示港口装卸费结算信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示港口装卸费结算信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "151", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getPortHandlingFeeList")
    public RESTfulResult getPortHandlingFeeList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                Integer pageNum,
                                                Integer pageSize,
                                                Integer apiId,
                                                String con) {
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_port_handling_fee_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> detailListTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            detailListTotal = bmsportHandlingFeeService.getPortHandlingFeeList(mapValue);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_port_handling_fee_list");
            //添加id
            map.put("indexId", "feeId");
            detailListTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(detailListTotal);
            esFeign.insertIndex(detailListTotal);
            //删除
            detailListTotal.remove(detailListTotal.size() - 1);
        }
        if (detailListTotal == null) {
            detailListTotal = bmsportHandlingFeeService.getPortHandlingFeeList(mapValue);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmsportHandlingFeeService.getPortHandlingFeeList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, detailListTotal, columnList);
        return success(data);
    }

    /**
     * 展示批次信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示批次信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "115", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getBatch")
    public RESTfulResult getBatch(@RequestBody(required = false) Map<String, Object> mapValue,
                                  Integer pageNum,
                                  Integer pageSize,
                                  Integer apiId) {
        List<Map<String, Object>> list = bmsshipStatementService.getBatch(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmsshipStatementService.getBatch(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    /**
     * 新增港口装卸费结算
     *
     * @param map
     * @return
     */
    @ApiModelProperty(value = "新增港口装卸费结算")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "港口装卸费字段", required = false, dataType = "java.util.List"),
    })
    @PostMapping("/addPortHandlingFee")
    public RESTfulResult addPortHandlingFee(@RequestBody Map<String, Object> map) throws Exception {
        int code1 = bmsportHandlingFeeService.insert(map);
        return success(code1);
    }

    /**
     * 修改港口装卸费结算
     *
     * @param bmsportHandlingFee
     * @return
     */
    @ApiModelProperty(value = "修改港口装卸费结算")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "bmsportHandlingFee", value = "港口装卸费", required = false, dataType = "BmsportHandlingFee"),
    })
    @PostMapping("/updatePortHandlingFee")
    public RESTfulResult updatePortHandlingFee(@RequestBody BmsportHandlingFee bmsportHandlingFee) {
        int code1 = bmsportHandlingFeeService.update(bmsportHandlingFee);
        return success(code1);
    }

    /**
     * 查询修改数据渲染表单
     *
     * @param feeId
     * @return
     */
    @ApiOperation(value = "查询修改数据渲染表单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "feeId", value = "港口装卸费结算字段", required = true, paramType = "java.math.BigDecimal")
    })
    @PostMapping("/getFeeToUpdate/{feeId}")
    public RESTfulResult getFeeToUpdate(@PathVariable("feeId") BigDecimal feeId) {
        List<Map<String, Object>> tmsshipLoadShipResult = bmsportHandlingFeeService.getFeeToUpdate(feeId);
        return success(tmsshipLoadShipResult);
    }

    /**
     * 逻辑删除港口装卸费结算
     *
     * @param feeId
     * @return
     */
    @ApiModelProperty(value = "逻辑删除港口装卸费结算")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "feeId", value = "主键id", required = false, dataType = "java.util.List"),
    })
    @PostMapping("/deletePortHandlingFee/{feeId}")
    public RESTfulResult deletePortHandlingFee(@PathVariable("feeId") String feeId) {
        int code1 = bmsportHandlingFeeService.deleteByUpdate(new BigDecimal(feeId));
        return success(code1);
    }

    /**
     * 获取物资下拉
     *
     * @return
     */
    @GetMapping(value = "/getMaterialId")
    public RESTfulResult getMaterialId() {
        List<Map<String, Object>> list = bmsportHandlingFeeService.getMaterialId();
        return success(list);
    }

    /**
     * 获取价格下拉
     *
     * @return
     */
    @GetMapping(value = "/getPriceId")
    public RESTfulResult getPriceId() {
        List<Map<String, Object>> list = bmsportHandlingFeeService.getPriceId();
        return success(list);
    }

}
