package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.feign.JoinApiFeign;
import com.steerinfo.dil.mapper.BmsportHandlingFeeMapper;
import com.steerinfo.dil.model.BmsportHandlingFee;
import com.steerinfo.dil.service.IBmsportHandlingFeeService;
import com.steerinfo.dil.util.EASUtil;
import com.steerinfo.dil.util.NoUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/27 14:14
 * @Version:V2.0
 */
@Service
public class BmsportHandlingFeeServiceImpl implements IBmsportHandlingFeeService {

    @Autowired
    BmsportHandlingFeeMapper bmsportHandlingFeeMapper;
    @Autowired
    BmstruckFormulaServiceImpl bmstruckFormulaService;
    @Autowired
    JoinApiFeign joinApiFeign;
    @Autowired
    NoUtil noUtil;
    @Autowired
    EASUtil easUtil;

    /**
     * 修改港口装卸费结算
     * @param bmsportHandlingFee
     * @return
     */
    @Override
    public int update(BmsportHandlingFee bmsportHandlingFee) {
        bmsportHandlingFee.setUpdateTime(new Date());
        return bmsportHandlingFeeMapper.updateByPrimaryKeySelective(bmsportHandlingFee);
    }

    /**
     * 逻辑删除港口装卸费结算
     * @param feeId
     * @return
     */
    @Override
    public int deleteByUpdate(BigDecimal feeId) {
        BmsportHandlingFee bmsportHandlingFee = bmsportHandlingFeeMapper.selectByPrimaryKey(feeId);
        bmsportHandlingFee.setDeleted(new BigDecimal(1));
        return bmsportHandlingFeeMapper.updateByPrimaryKeySelective(bmsportHandlingFee);
    }

    /**
     * 新增港口装卸费结算
     * @param map
     * @return
     */
    @Transactional
    @Override
    public int insert(Map<String,Object> map) throws Exception {
        Map<String,Object> mapVal = (Map<String, Object>) map.get("mapVal");
        Map<String,Object> rowMap = (Map<String, Object>) map.get("rowMap");
        BigDecimal materialId = new BigDecimal((Integer) rowMap.get("materialId")) ;
        String feeForeignShipName = (String) rowMap.get("foreignShipName");
        BigDecimal feeId = selectMaxId();
        String feeNo = noUtil.setResultNo("GKZXF", feeId);
        BigDecimal feeMaterialTonnage = new BigDecimal((String) mapVal.get("feeMaterialTonnage"));
        List<Map<String,Object>> priceList = bmsportHandlingFeeMapper.getPriceId();
        Map<String, Object> priceMap = priceList.get(0);
        BigDecimal priceId = (BigDecimal) priceMap.get("priceId");
        BigDecimal fee = bmstruckFormulaService.generatePortHandlingFee(feeMaterialTonnage, priceId);
        DecimalFormat df = new DecimalFormat("0.00");
        String format = df.format(fee.doubleValue());
        BigDecimal feeValue = new BigDecimal(format);
        BmsportHandlingFee bmsportHandlingFee = new BmsportHandlingFee();
        bmsportHandlingFee.setDeleted(new BigDecimal(0));
        bmsportHandlingFee.setPriceId(priceId);
        bmsportHandlingFee.setFeeId(feeId);
        bmsportHandlingFee.setFeeNo(feeNo);
        bmsportHandlingFee.setFeeMaterialTonnage(feeMaterialTonnage);
        bmsportHandlingFee.setFeeValue(feeValue);
        bmsportHandlingFee.setMaterialId(materialId);
        bmsportHandlingFee.setFeeForeignShipName(feeForeignShipName);
        // 设置常规字段
        bmsportHandlingFee.setInsertTime(new Date());
        bmsportHandlingFee.setInsertUsername("admin");
        bmsportHandlingFee.setUpdateTime(new Date());
        bmsportHandlingFee.setUpdateUsername("admin");
        bmsportHandlingFee.setInsertUpdateRemark("无");
        int code = bmsportHandlingFeeMapper.insertSelective(bmsportHandlingFee);
        // 调用金蝶接口
        Map<String, Object> input = joinApiFeign.getPortFee(feeId.intValue());
        Map<String, Object> totalMap = easUtil.getTotalMap();
        totalMap.put("input",input);
        joinApiFeign.WSFaceWay(totalMap);
//        if (result.equals()) {
//
//        }
        return code;
    }

    /**
     * 展示港口装卸费列表
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getPortHandlingFeeList(Map<String, Object> mapValue) {
        return bmsportHandlingFeeMapper.getPortHandlingFeeList(mapValue);
    }

    /**
     * 查询最大id
     * @return
     */
    @Override
    public BigDecimal selectMaxId() {
        return bmsportHandlingFeeMapper.selectHandlingId();
    }

    /**
     * 查询修改渲染数据
     * @param feeId
     * @return
     */
    @Override
    public List<Map<String,Object>> getFeeToUpdate(BigDecimal feeId) {
        return bmsportHandlingFeeMapper.getFeeToUpdate(feeId);
    }

    /**
     * 获取物资id下拉
     * @return
     */
    @Override
    public List<Map<String, Object>> getMaterialId() {
        return bmsportHandlingFeeMapper.getMaterialId();
    }

    /**
     * 获取单价下拉
     * @return
     */
    @Override
    public List<Map<String, Object>> getPriceId() {
        return bmsportHandlingFeeMapper.selectPriceId();
    }
}
